@@ -359,7 +359,7 @@ class KubeCluster(SpecCluster):
 
     Examples
     --------
-    >>> from dask_kubernetes import KubeCluster, make_pod_spec
+    >>> from dask_kubernetes.classic import KubeCluster, make_pod_spec
     >>> pod_spec = make_pod_spec(image='ghcr.io/dask/dask:latest',
     ...                          memory_limit='4G', memory_request='4G',
     ...                          cpu_limit=1, cpu_request=1,
